import MagicString from 'magic-string';
import ts from 'typescript';
import { type AST, type AttributeNode, type ComponentChildren } from '../ast';
import type { ASTSerializer, TransformContext } from '../transform';
import { type JSXAttrNamespace, type JSXElementNode, type JSXEventNamespace, type JSXNamespace } from './parse-jsx';
export declare function isComponentTagName(tagName: string): boolean;
export declare function getTagName(node: ts.JsxElement | ts.JsxSelfClosingElement): string;
export declare function isValidAttrNamespace(namespace: any): namespace is JSXAttrNamespace;
export declare function isValidNamespace(namespace: any): namespace is JSXNamespace;
export declare function isValidEventNamespace(namespace: string): namespace is JSXEventNamespace;
export declare function toAttributeName(name: string): string;
export declare function toPropertyName(name: string): string;
export declare function isTrueBoolExpression(node: ts.Expression): boolean;
export declare function isFalseBoolExpression(node: ts.Expression): boolean;
export declare function isBoolExpression(node: ts.Expression): boolean;
export declare function isStringExpression(node: ts.Expression): boolean;
export declare function isStaticExpression(node: ts.Expression): boolean;
export declare function overwrite(code: MagicString, node: ts.Node, content: string): void;
export declare function insertAfter(code: MagicString, node: ts.Node, content: string): void;
export declare function isEmptyNode(node: ts.Node): boolean;
export declare function isEmptyExpressionNode(node: ts.Node): boolean;
export declare function isEmptyTextNode(node: ts.Node): boolean;
export declare function filterEmptyJSXChildNodes(children: ts.JsxChild[]): ts.JsxChild[];
export declare function filterDOMElements(children: ts.JsxChild[]): JSXElementNode[];
export declare function serializeComponentProp(serializer: ASTSerializer, node: AttributeNode, ctx: TransformContext): string;
export declare function serializeChildren(serializer: ASTSerializer, children: ComponentChildren[], ctx: TransformContext, component?: boolean): string;
export declare function serializeComponentChildrenProp(serializer: ASTSerializer, children: ComponentChildren[], ctx: TransformContext): string;
export declare function serializeParentExpression(serializer: ASTSerializer, node: {
    value: string;
    ref: ts.Node;
    children?: AST[];
}, ctx: TransformContext, hof?: string | false): string;
export declare function serializeCreateComponent(createId: string, mergeId: string, tagName: string, props: string[], spreads: string[]): {
    createComponent: string;
    shouldMergeProps: boolean;
};
