import kleur from 'kleur';
import type { Node, SourceFile } from 'typescript';
export declare const enum LogLevel {
    Silent = 0,
    Error = 1,
    Warn = 2,
    Info = 3,
    Verbose = 4
}
export declare const LogLevelColor: Readonly<{
    0: kleur.Color;
    1: kleur.Color;
    2: kleur.Color;
    3: kleur.Color;
    4: kleur.Color;
}>;
export type LogLevelName = 'silent' | 'error' | 'warn' | 'info' | 'verbose';
export declare function mapLogLevelStringToNumber(level: LogLevelName): LogLevel;
export declare function mapLogLevelToString(level: LogLevel): string;
export declare const clearTerminal: () => void;
export declare function setGlobalLogLevel(level: LogLevel): void;
export type Logger = (text: unknown | (() => string), level?: LogLevel) => void;
export declare const log: Logger;
export type TimedLogger = (message: string, startTime: [number, number], level?: LogLevel) => void;
export declare const logTime: TimedLogger;
export declare function formatPluginName(name: string): string;
export declare function getDefaultPluginName(): string;
export type StackTraceLogger = (message: string, stack: string, level?: LogLevel) => void;
export declare const logStackTrace: StackTraceLogger;
export type DiagnosticReporterByLine = (message: string, file: SourceFile, line: number, level?: LogLevel) => void;
export declare let testDiagnostics: {
    message: string;
    print: string;
    level: LogLevel;
}[];
export declare const reportDiagnosticByLine: DiagnosticReporterByLine;
export type DiagnosticReporterByNode = (message: string, node: Node, level?: LogLevel) => void;
export declare const reportDiagnosticByNode: DiagnosticReporterByNode;
